@@ -133,17 +133,35 @@ packageBartResults <- function(fit, samples, burnInSigma, burnInK, combineChains
 .kDefault <- quote(if (control@binary) quote(chi(1.25, Inf)) else 2)
 
 bart2 <- function(
-  formula, data, test, subset, weights, offset, offset.test = offset,
-  sigest = NA_real_, sigdf = 3.0, sigquant = 0.90,
+  formula,
+  data,
+  test,
+  subset,
+  weights,
+  offset,
+  offset.test = offset,
+  sigest = NA_real_,
+  sigdf = 3.0,
+  sigquant = 0.90,
   k = NULL,
-  power = 2.0, base = 0.95, split.probs = 1 / num.vars,
+  power = 2.0,
+  base = 0.95,
+  split.probs = 1 / num.vars,
   n.trees = 75L,
-  n.samples = 500L, n.burn = 500L,
-  n.chains = 4L, n.threads = min(dbarts::guessNumCores(), n.chains), combineChains = FALSE,
-  n.cuts = 100L, useQuantiles = FALSE,
-  n.thin = 1L, keepTrainingFits = TRUE,
-  printEvery = 100L, printCutoffs = 0L,
-  verbose = TRUE, keepTrees = FALSE, keepCall = TRUE,
+  n.samples = 500L,
+  n.burn = 500L,
+  n.chains = 4L,
+  n.threads = min(dbarts::guessNumCores(), n.chains),
+  combineChains = FALSE,
+  n.cuts = 100L,
+  useQuantiles = FALSE,
+  n.thin = 1L,
+  keepTrainingFits = TRUE,
+  printEvery = 100L,
+  printCutoffs = 0L,
+  verbose = TRUE,
+  keepTrees = FALSE,
+  keepCall = TRUE,
   samplerOnly = FALSE,
   seed = NA_integer_,
   proposal.probs = NULL,
@@ -224,8 +242,9 @@ bart2 <- function(
     control@keepTrainingFits <- FALSE
     control@verbose <- FALSE
     sampler$setControl(control)
-
-    samples <- sampler$run(0L, control@n.burn, FALSE)
+    sampler$startThreads()
+    
+    samples <- sampler$run(0L, control@n.burn, updateState = FALSE)
     if (!is.null(samples$sigma)) burnInSigma <- samples$sigma
     if (!is.null(samples[["k"]])) burnInK <- samples[["k"]]
     
@@ -238,8 +257,10 @@ bart2 <- function(
 
     samples <- sampler$run(0L, control@n.samples, updateState = FALSE)
   } else {
+    sampler$startThreads()
     samples <- sampler$run(updateState = FALSE)
   }
+  sampler$stopThreads()
 
   result <- packageBartResults(sampler, samples, burnInSigma, burnInK, combineChains, keepSampler)
   # needed to extract ppd
@@ -320,8 +341,9 @@ bart <- function(
     control@keepTrainingFits <- FALSE
     control@verbose <- FALSE
     sampler$setControl(control)
+    sampler$startThreads()
     
-    samples <- sampler$run(0L, control@n.burn, FALSE)
+    samples <- sampler$run(0L, control@n.burn, updateState = FALSE)
     if (!is.null(samples$sigma)) burnInSigma <- samples$sigma
     if (!is.null(samples[["k"]])) burnInK <- samples[["k"]]
     
@@ -333,8 +355,10 @@ bart <- function(
 
     samples <- sampler$run(0L, control@n.samples, updateState = FALSE)
   } else {
+    sampler$startThreads()
     samples <- sampler$run(updateState = FALSE)
   }
+  sampler$stopThreads()
 
   result <- packageBartResults(sampler, samples, burnInSigma, burnInK, combinechains, keepsampler)
   
