@@ -11,8 +11,9 @@ pdbart.getAndInitializeSampler <- function(bartCall, evalEnv)
   keepTrainingFits <- control@keepTrainingFits
   control@verbose <- control@keepTrainingFits <- FALSE
   sampler$setControl(control)
-  
-  samples <- sampler$run(0L, sampler$control@n.burn, FALSE)
+  sampler$startThreads()
+
+  samples <- sampler$run(0L, sampler$control@n.burn, updateState = FALSE)
   fit <- list(first.sigma = samples$sigma)
   control@verbose <- verbose
   control@keepTrainingFits <- keepTrainingFits
@@ -156,6 +157,7 @@ pdbart <- function (
       offset <- offset + numObservations * numLevels[j]
     }
   }
+  sampler$stopThreads()
   
   if (is.null(colnames(sampler$data@x)))
     xLabels <- paste0('x', xind)
@@ -324,6 +326,7 @@ pd2bart <- function(
       fit[["yhat.test"]] <- NULL
     }
   }
+  sampler$stopThreads()
  
   if (is.null(colnames(sampler$data@x)))
     xLabels <- paste0('x', xind)
