@@ -2,8 +2,17 @@
 #define EXTERNAL_IO_H
 
 #include <external/R.h>  // R_FlushConsole
+
+#include <Rversion.h>
+
+#if R_VERSION >= R_Version(3, 6, 2)
+#define USE_FC_LEN_T
+#endif
+
 #include <R_ext/Print.h> // Rprintf
 
+#undef USE_FC_LEN_T
+
 // defines a crossplatform NORETURN http://www.open-std.org/jtc1/sc22/wg14/www/docs/n1453.htm
 #if _MSC_VER >= 1310 
 #  define NORETURN _declspec(noreturn)
